@@ -17,6 +17,10 @@
 #' That function adjusts the argument if it is a nonworking day according to calendar.
 #' @param adjust.to is a function to be used with the \code{bizdays}'s \code{to} argument.
 #' See also \code{adjust.from}.
+#' @param financial is a logical argument that defaults to TRUE.
+#' This argument defines the calendar as a financial or a non financial calendar.
+#' Financial calendars don't consider the ending business day when counting working days in \code{bizdays}.
+#' \code{bizdays} calls for non financial calendars are greater than financial calendars calls by one day.
 #' 
 #' @details
 #' The arguments \code{start.date} and \code{end.date} can be set but once they aren't and \code{holidays}
@@ -67,16 +71,6 @@
 #' bizdays('2016-01-01', '2016-03-14', 'Actual')
 NULL
 
-#' @export
-#' @rdname create.calendar
-Calendar <- function(holidays=integer(0),
-                     start.date=NULL, end.date=NULL, name=NULL,
-                     weekdays=NULL, adjust.from=adjust.next,
-                     adjust.to=adjust.previous) {
-  warning('This function will be deprecated, use create.calendar instead.')
-  Calendar_(holidays, start.date, end.date, name, weekdays, adjust.from, adjust.to)
-}
-
 rev_index <- function(idx) {
   ridx <- cumsum(idx) + 1 - as.integer(idx)
   ridx[ridx > sum(idx)] <- sum(idx)
@@ -86,12 +80,14 @@ rev_index <- function(idx) {
 Calendar_ <- function (holidays=integer(0),
                        start.date=NULL, end.date=NULL, name=NULL,
                        weekdays=NULL, adjust.from=adjust.next,
-                       adjust.to=adjust.previous) {
+                       adjust.to=adjust.previous, financial = TRUE) {
   
   if (length(holidays) != 0 && all(is.null(weekdays)))
     warning('You provided holidays without set weekdays.\n',
             'That setup leads to inconsistencies!')
   that <- list()
+  # financial argument
+  that$financial <- financial
   # adjust functions
   that$adjust.from <- adjust.from
   that$adjust.to <- adjust.to
@@ -194,10 +190,14 @@ create.calendar <- function(name,
                             holidays=integer(0),
                             weekdays=NULL, 
                             start.date=NULL, end.date=NULL,
-                            adjust.from=adjust.none, adjust.to=adjust.none) {
+                            adjust.from=adjust.none, adjust.to=adjust.none,
+                            financial=TRUE) {
   cal <- Calendar_(holidays=holidays, weekdays=weekdays, name=name,
                   start.date=start.date, end.date=end.date,
-                  adjust.from=adjust.from, adjust.to=adjust.to)
+                  adjust.from=adjust.from, adjust.to=adjust.to,
+                  financial=financial)
+  cal$adjust.from_label = deparse(substitute(adjust.from))
+  cal$adjust.to_label = deparse(substitute(adjust.to))
   .CALENDAR_REGISTER[[cal$name]] <- cal
   invisible(cal)
 }
@@ -270,11 +270,18 @@ weekdays.character <- function(x, ...) {
 #' @export
 print.Calendar <- function(x, ...) {
   cal <- x
-  cat('Calendar:', cal$name,
-      '\nRange:', format(as.Date(cal$start.date, origin='1970-01-01'), '%Y-%m-%d'),
-      'to', format(as.Date(cal$end.date, origin='1970-01-01'), '%Y-%m-%d'),
-      '\nweekdays:', cal$weekdays,
-      '\n')
+  lab_holidays = paste0(length(cal$holidays), ' holidays')
+  lab_weekdays_1 = if (length(cal$weekdays)) paste0('(', paste(cal$weekdays, collapse = ', '), ')') else ''
+  lab_weekdays = paste0(length(cal$weekdays), ' weekdays ', lab_weekdays_1)
+  lab_financial = if (cal$financial) 'financial' else 'non financial'
+  cat(cal$name, lab_financial, 'calendar', '\n ',
+      lab_holidays, '\n ',
+      lab_weekdays, '\n ',
+      'range from', format(as.Date(cal$start.date, origin='1970-01-01'), '%Y-%m-%d'),
+      'to', format(as.Date(cal$end.date, origin='1970-01-01'), '%Y-%m-%d'), '\n')
+  cat('bizdays arguments adjust\n',
+      sprintf(' %-6s%s', 'from:', cal$adjust.from_label), '\n',
+      sprintf(' %-6s%s', 'to:', cal$adjust.to_label), '\n')
   invisible(x)
 }
 
